@@ -86,11 +86,11 @@ void init_styles (X_display *disp, X_resman *xrm)
     Colors.midi_co2 = disp->alloc_color (xrm->get (".color.midi.c02", "green"),   Colors.white);
     Colors.midi_co3 = disp->alloc_color (xrm->get (".color.midi.c03", "coral"),   Colors.white);
 
-    XftFonts.spla1  = disp->alloc_xftfont (xrm->get (".font.spla1",  "times:bold:pixelsize=24"));
-    XftFonts.spla2  = disp->alloc_xftfont (xrm->get (".font.spla2",  "times:bold:pixelsize=16"));
+    XftFonts.spla1  = disp->alloc_xftfont (xrm->get (".font.spla1",  "serif:bold:pixelsize=20"));
+    XftFonts.spla2  = disp->alloc_xftfont (xrm->get (".font.spla2",  "serif:bold:pixelsize=12"));
     XftFonts.main   = disp->alloc_xftfont (xrm->get (".font.main",   "luxi:pixelsize=12"));  
-    XftFonts.large  = disp->alloc_xftfont (xrm->get (".font.large",  "times:bold:pixelsize=18"));
-    XftFonts.stops  = disp->alloc_xftfont (xrm->get (".font.stops",  "times:bold:pixelsize=14"));
+    XftFonts.large  = disp->alloc_xftfont (xrm->get (".font.large",  "serif:bold:pixelsize=16"));
+    XftFonts.stops  = disp->alloc_xftfont (xrm->get (".font.stops",  "serif:bold:pixelsize=13"));
     XftFonts.button = disp->alloc_xftfont (xrm->get (".font.button", "luxi:pixelsize=12"));
     XftFonts.scales = disp->alloc_xftfont (xrm->get (".font.scales", "luxi:pixelsize=9"));
     XftFonts.midimt = disp->alloc_xftfont (xrm->get (".font.midimt", "luxi:bold:pixelsize=9"));
